==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/compton-conf/compton-conf_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Nastavení zvláštních efektů</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Stín</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="30"/>
        <source>The blur radius for shadows</source>
        <translation>Poloměr neostrosti</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="40"/>
        <source>The left offset for shadows</source>
        <translation>Posun zleva</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="54"/>
        <source>The top offset for shadows</source>
        <translation>Posun shora</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="68"/>
        <source>The translucency for shadows</source>
        <translation>Propustnost světla</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="75"/>
        <source>Color of shadow</source>
        <translation>Barva stínu</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="89"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Opravy zvláštností oken ARGB</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="92"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Vypnout masku stínu za oknem</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="99"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Žádné stíny při posunování oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="106"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Žádné stíny u oken panelů</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="113"/>
        <source>Enabled client-side shadows on windows</source>
        <translation>Povolit kreslení stínů oken na straně klienta</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="120"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Žádné stíny u všech tvarovaných oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="138"/>
        <source>Opacity</source>
        <translation>Neprůhlednost</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="147"/>
        <source>The opacity for menus</source>
        <translation>Neprůhlednost nabídek</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="154"/>
        <source>Default opacity of inactive windows</source>
        <translation>Výchozí neprůhlednost nečinných oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="161"/>
        <source>Default opacity for active windows</source>
        <translation>Výchozí neprůhlednost činných oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="168"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Neprůhlednost titulkových pruhů oken a okrajů</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="175"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender Backend: Velikost kroku pro obrázky s průsvitností
(vyšší hodnoty mohou vést k menšímu používání zdrojů X)</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="183"/>
        <source>Dim inactive windows</source>
        <translation>Ztmavit nečinná okna</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="190"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Ztmavení je nezávislé na neprůhlednosti okna</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="197"/>
        <source>Blur background of transparent windows</source>
        <translation>Rozmazat pozadí průhledných oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="204"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Rozmazat také pozadí neprůhledných oken s průhlednými rámečky</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="211"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Poloměr rozmazání je nezávislý na neprůhlednosti okna</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="279"/>
        <source>Fade</source>
        <translation>Prolínat</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="285"/>
        <source>Fade windows during opacity changes</source>
        <translation>Účinek prolínání při změnách neprůhlednosti</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="292"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Čas mezi kroky prolínání v milisekundách</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="299"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Změna neprůhlednosti mezi kroky při postupném zesilování</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="306"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Změna neprůhlednosti mezi kroky při postupném zeslabování</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="313"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Vyhnout se účinku prolínání při otevírání/zavírání oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="356"/>
        <source>Other</source>
        <translation>Jiné</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="362"/>
        <source>Not implemented yet</source>
        <translation>Neprovedeno</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="375"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="179"/>
        <source>About ComptonConf</source>
        <translation>O ComptonConf</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="180"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - nástroj na nastavení pro compton

Autorské právo (C) 2013
Autor: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/compton-conf/compton-conf_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Nastavení zvláštních efektů</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Stín</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="30"/>
        <source>The blur radius for shadows</source>
        <translation>Poloměr neostrosti</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="40"/>
        <source>The left offset for shadows</source>
        <translation>Posun zleva</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="54"/>
        <source>The top offset for shadows</source>
        <translation>Posun shora</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="68"/>
        <source>The translucency for shadows</source>
        <translation>Propustnost světla</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="75"/>
        <source>Color of shadow</source>
        <translation>Barva stínu</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="89"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Opravy zvláštností oken ARGB</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="92"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Vypnout masku stínu za oknem</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="99"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Žádné stíny při posunování oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="106"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Žádné stíny u oken panelů</translation>
    </message>
    <message>
        <source>Enabled client-side shadows on windows</source>
        <translation type="vanished">Povolit kreslení stínů oken na straně klienta</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="113"/>
        <source>Enable client-side shadows on windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="120"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Žádné stíny u všech tvarovaných oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="138"/>
        <source>Opacity</source>
        <translation>Neprůhlednost</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="147"/>
        <source>The opacity for menus</source>
        <translation>Neprůhlednost nabídek</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="154"/>
        <source>Default opacity of inactive windows</source>
        <translation>Výchozí neprůhlednost nečinných oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="161"/>
        <source>Default opacity for active windows</source>
        <translation>Výchozí neprůhlednost činných oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="168"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Neprůhlednost titulkových pruhů oken a okrajů</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="175"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender Backend: Velikost kroku pro obrázky s průsvitností
(vyšší hodnoty mohou vést k menšímu používání zdrojů X)</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="183"/>
        <source>Dim inactive windows</source>
        <translation>Ztmavit nečinná okna</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="190"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Ztmavení je nezávislé na neprůhlednosti okna</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="197"/>
        <source>Blur background of transparent windows</source>
        <translation>Rozmazat pozadí průhledných oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="204"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Rozmazat také pozadí neprůhledných oken s průhlednými rámečky</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="211"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Poloměr rozmazání je nezávislý na neprůhlednosti okna</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="279"/>
        <source>Fade</source>
        <translation>Prolínat</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="285"/>
        <source>Fade windows during opacity changes</source>
        <translation>Účinek prolínání při změnách neprůhlednosti</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="292"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Čas mezi kroky prolínání v milisekundách</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="299"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Změna neprůhlednosti mezi kroky při postupném zesilování</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="306"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Změna neprůhlednosti mezi kroky při postupném zeslabování</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="313"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Vyhnout se účinku prolínání při otevírání/zavírání oken</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="356"/>
        <source>Other</source>
        <translation>Jiné</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="368"/>
        <source>Rendering backend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="380"/>
        <source>X Render</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="387"/>
        <source>GLX (OpenGL)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not implemented yet</source>
        <translation type="vanished">Neprovedeno</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="403"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="206"/>
        <source>About ComptonConf</source>
        <translation>O ComptonConf</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="207"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - nástroj na nastavení pro compton

Autorské právo (C) 2013
Autor: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
